==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/cdk/JsiiPythonTarget.java <==
package io.github.cdklabs.projen.cdk;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.664Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.cdk.JsiiPythonTarget")
@software.amazon.jsii.Jsii.Proxy(JsiiPythonTarget.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface JsiiPythonTarget extends software.amazon.jsii.JsiiSerializable, io.github.cdklabs.projen.release.PyPiPublishOptions {

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getDistName();

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getModule();

    /**
     * @return a {@link Builder} of {@link JsiiPythonTarget}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link JsiiPythonTarget}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<JsiiPythonTarget> {
        java.lang.String distName;
        java.lang.String module;
        java.lang.String twinePasswordSecret;
        java.lang.String twineRegistryUrl;
        java.lang.String twineUsernameSecret;

        /**
         * Sets the value of {@link JsiiPythonTarget#getDistName}
         * @param distName the value to be set. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder distName(java.lang.String distName) {
            this.distName = distName;
            return this;
        }

        /**
         * Sets the value of {@link JsiiPythonTarget#getModule}
         * @param module the value to be set. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder module(java.lang.String module) {
            this.module = module;
            return this;
        }

        /**
         * Sets the value of {@link JsiiPythonTarget#getTwinePasswordSecret}
         * @param twinePasswordSecret The GitHub secret which contains PyPI password.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder twinePasswordSecret(java.lang.String twinePasswordSecret) {
            this.twinePasswordSecret = twinePasswordSecret;
            return this;
        }

        /**
         * Sets the value of {@link JsiiPythonTarget#getTwineRegistryUrl}
         * @param twineRegistryUrl The registry url to use when releasing packages.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder twineRegistryUrl(java.lang.String twineRegistryUrl) {
            this.twineRegistryUrl = twineRegistryUrl;
            return this;
        }

        /**
         * Sets the value of {@link JsiiPythonTarget#getTwineUsernameSecret}
         * @param twineUsernameSecret The GitHub secret which contains PyPI user name.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder twineUsernameSecret(java.lang.String twineUsernameSecret) {
            this.twineUsernameSecret = twineUsernameSecret;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link JsiiPythonTarget}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public JsiiPythonTarget build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link JsiiPythonTarget}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements JsiiPythonTarget {
        private final java.lang.String distName;
        private final java.lang.String module;
        private final java.lang.String twinePasswordSecret;
        private final java.lang.String twineRegistryUrl;
        private final java.lang.String twineUsernameSecret;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.distName = software.amazon.jsii.Kernel.get(this, "distName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.module = software.amazon.jsii.Kernel.get(this, "module", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.twinePasswordSecret = software.amazon.jsii.Kernel.get(this, "twinePasswordSecret", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.twineRegistryUrl = software.amazon.jsii.Kernel.get(this, "twineRegistryUrl", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.twineUsernameSecret = software.amazon.jsii.Kernel.get(this, "twineUsernameSecret", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.distName = java.util.Objects.requireNonNull(builder.distName, "distName is required");
            this.module = java.util.Objects.requireNonNull(builder.module, "module is required");
            this.twinePasswordSecret = builder.twinePasswordSecret;
            this.twineRegistryUrl = builder.twineRegistryUrl;
            this.twineUsernameSecret = builder.twineUsernameSecret;
        }

        @Override
        public final java.lang.String getDistName() {
            return this.distName;
        }

        @Override
        public final java.lang.String getModule() {
            return this.module;
        }

        @Override
        public final java.lang.String getTwinePasswordSecret() {
            return this.twinePasswordSecret;
        }

        @Override
        public final java.lang.String getTwineRegistryUrl() {
            return this.twineRegistryUrl;
        }

        @Override
        public final java.lang.String getTwineUsernameSecret() {
            return this.twineUsernameSecret;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("distName", om.valueToTree(this.getDistName()));
            data.set("module", om.valueToTree(this.getModule()));
            if (this.getTwinePasswordSecret() != null) {
                data.set("twinePasswordSecret", om.valueToTree(this.getTwinePasswordSecret()));
            }
            if (this.getTwineRegistryUrl() != null) {
                data.set("twineRegistryUrl", om.valueToTree(this.getTwineRegistryUrl()));
            }
            if (this.getTwineUsernameSecret() != null) {
                data.set("twineUsernameSecret", om.valueToTree(this.getTwineUsernameSecret()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.cdk.JsiiPythonTarget"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            JsiiPythonTarget.Jsii$Proxy that = (JsiiPythonTarget.Jsii$Proxy) o;

            if (!distName.equals(that.distName)) return false;
            if (!module.equals(that.module)) return false;
            if (this.twinePasswordSecret != null ? !this.twinePasswordSecret.equals(that.twinePasswordSecret) : that.twinePasswordSecret != null) return false;
            if (this.twineRegistryUrl != null ? !this.twineRegistryUrl.equals(that.twineRegistryUrl) : that.twineRegistryUrl != null) return false;
            return this.twineUsernameSecret != null ? this.twineUsernameSecret.equals(that.twineUsernameSecret) : that.twineUsernameSecret == null;
        }

        @Override
        public final int hashCode() {
            int result = this.distName.hashCode();
            result = 31 * result + (this.module.hashCode());
            result = 31 * result + (this.twinePasswordSecret != null ? this.twinePasswordSecret.hashCode() : 0);
            result = 31 * result + (this.twineRegistryUrl != null ? this.twineRegistryUrl.hashCode() : 0);
            result = 31 * result + (this.twineUsernameSecret != null ? this.twineUsernameSecret.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/cdk/JsiiPythonTarget.java <==
package io.github.cdklabs.projen.cdk;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.339Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.cdk.JsiiPythonTarget")
@software.amazon.jsii.Jsii.Proxy(JsiiPythonTarget.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface JsiiPythonTarget extends software.amazon.jsii.JsiiSerializable, io.github.cdklabs.projen.release.PyPiPublishOptions {

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getDistName();

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getModule();

    /**
     * @return a {@link Builder} of {@link JsiiPythonTarget}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link JsiiPythonTarget}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<JsiiPythonTarget> {
        java.lang.String distName;
        java.lang.String module;
        java.lang.String twinePasswordSecret;
        java.lang.String twineRegistryUrl;
        java.lang.String twineUsernameSecret;
        java.util.List<io.github.cdklabs.projen.github.workflows.JobStep> postPublishSteps;
        java.util.List<io.github.cdklabs.projen.github.workflows.JobStep> prePublishSteps;
        io.github.cdklabs.projen.github.workflows.Tools publishTools;

        /**
         * Sets the value of {@link JsiiPythonTarget#getDistName}
         * @param distName the value to be set. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder distName(java.lang.String distName) {
            this.distName = distName;
            return this;
        }

        /**
         * Sets the value of {@link JsiiPythonTarget#getModule}
         * @param module the value to be set. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder module(java.lang.String module) {
            this.module = module;
            return this;
        }

        /**
         * Sets the value of {@link JsiiPythonTarget#getTwinePasswordSecret}
         * @param twinePasswordSecret The GitHub secret which contains PyPI password.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder twinePasswordSecret(java.lang.String twinePasswordSecret) {
            this.twinePasswordSecret = twinePasswordSecret;
            return this;
        }

        /**
         * Sets the value of {@link JsiiPythonTarget#getTwineRegistryUrl}
         * @param twineRegistryUrl The registry url to use when releasing packages.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder twineRegistryUrl(java.lang.String twineRegistryUrl) {
            this.twineRegistryUrl = twineRegistryUrl;
            return this;
        }

        /**
         * Sets the value of {@link JsiiPythonTarget#getTwineUsernameSecret}
         * @param twineUsernameSecret The GitHub secret which contains PyPI user name.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder twineUsernameSecret(java.lang.String twineUsernameSecret) {
            this.twineUsernameSecret = twineUsernameSecret;
            return this;
        }

        /**
         * Sets the value of {@link JsiiPythonTarget#getPostPublishSteps}
         * @param postPublishSteps Steps to execute after executing the publishing command.
         *                         These can be used
         *                         to add/update the release artifacts ot any other tasks needed.
         *                         <p>
         *                         Note that when using this in <code>publishToGitHubReleases</code> this will override steps added via <code>addGitHubPostPublishingSteps</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder postPublishSteps(java.util.List<? extends io.github.cdklabs.projen.github.workflows.JobStep> postPublishSteps) {
            this.postPublishSteps = (java.util.List<io.github.cdklabs.projen.github.workflows.JobStep>)postPublishSteps;
            return this;
        }

        /**
         * Sets the value of {@link JsiiPythonTarget#getPrePublishSteps}
         * @param prePublishSteps Steps to execute before executing the publishing command. These can be used to prepare the artifact for publishing if neede.
         *                        These steps are executed after <code>dist/</code> has been populated with the build
         *                        output.
         *                        <p>
         *                        Note that when using this in <code>publishToGitHubReleases</code> this will override steps added via <code>addGitHubPrePublishingSteps</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder prePublishSteps(java.util.List<? extends io.github.cdklabs.projen.github.workflows.JobStep> prePublishSteps) {
            this.prePublishSteps = (java.util.List<io.github.cdklabs.projen.github.workflows.JobStep>)prePublishSteps;
            return this;
        }

        /**
         * Sets the value of {@link JsiiPythonTarget#getPublishTools}
         * @param publishTools Additional tools to install in the publishing job.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder publishTools(io.github.cdklabs.projen.github.workflows.Tools publishTools) {
            this.publishTools = publishTools;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link JsiiPythonTarget}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public JsiiPythonTarget build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link JsiiPythonTarget}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements JsiiPythonTarget {
        private final java.lang.String distName;
        private final java.lang.String module;
        private final java.lang.String twinePasswordSecret;
        private final java.lang.String twineRegistryUrl;
        private final java.lang.String twineUsernameSecret;
        private final java.util.List<io.github.cdklabs.projen.github.workflows.JobStep> postPublishSteps;
        private final java.util.List<io.github.cdklabs.projen.github.workflows.JobStep> prePublishSteps;
        private final io.github.cdklabs.projen.github.workflows.Tools publishTools;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.distName = software.amazon.jsii.Kernel.get(this, "distName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.module = software.amazon.jsii.Kernel.get(this, "module", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.twinePasswordSecret = software.amazon.jsii.Kernel.get(this, "twinePasswordSecret", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.twineRegistryUrl = software.amazon.jsii.Kernel.get(this, "twineRegistryUrl", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.twineUsernameSecret = software.amazon.jsii.Kernel.get(this, "twineUsernameSecret", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.postPublishSteps = software.amazon.jsii.Kernel.get(this, "postPublishSteps", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.workflows.JobStep.class)));
            this.prePublishSteps = software.amazon.jsii.Kernel.get(this, "prePublishSteps", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.workflows.JobStep.class)));
            this.publishTools = software.amazon.jsii.Kernel.get(this, "publishTools", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.workflows.Tools.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.distName = java.util.Objects.requireNonNull(builder.distName, "distName is required");
            this.module = java.util.Objects.requireNonNull(builder.module, "module is required");
            this.twinePasswordSecret = builder.twinePasswordSecret;
            this.twineRegistryUrl = builder.twineRegistryUrl;
            this.twineUsernameSecret = builder.twineUsernameSecret;
            this.postPublishSteps = (java.util.List<io.github.cdklabs.projen.github.workflows.JobStep>)builder.postPublishSteps;
            this.prePublishSteps = (java.util.List<io.github.cdklabs.projen.github.workflows.JobStep>)builder.prePublishSteps;
            this.publishTools = builder.publishTools;
        }

        @Override
        public final java.lang.String getDistName() {
            return this.distName;
        }

        @Override
        public final java.lang.String getModule() {
            return this.module;
        }

        @Override
        public final java.lang.String getTwinePasswordSecret() {
            return this.twinePasswordSecret;
        }

        @Override
        public final java.lang.String getTwineRegistryUrl() {
            return this.twineRegistryUrl;
        }

        @Override
        public final java.lang.String getTwineUsernameSecret() {
            return this.twineUsernameSecret;
        }

        @Override
        public final java.util.List<io.github.cdklabs.projen.github.workflows.JobStep> getPostPublishSteps() {
            return this.postPublishSteps;
        }

        @Override
        public final java.util.List<io.github.cdklabs.projen.github.workflows.JobStep> getPrePublishSteps() {
            return this.prePublishSteps;
        }

        @Override
        public final io.github.cdklabs.projen.github.workflows.Tools getPublishTools() {
            return this.publishTools;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("distName", om.valueToTree(this.getDistName()));
            data.set("module", om.valueToTree(this.getModule()));
            if (this.getTwinePasswordSecret() != null) {
                data.set("twinePasswordSecret", om.valueToTree(this.getTwinePasswordSecret()));
            }
            if (this.getTwineRegistryUrl() != null) {
                data.set("twineRegistryUrl", om.valueToTree(this.getTwineRegistryUrl()));
            }
            if (this.getTwineUsernameSecret() != null) {
                data.set("twineUsernameSecret", om.valueToTree(this.getTwineUsernameSecret()));
            }
            if (this.getPostPublishSteps() != null) {
                data.set("postPublishSteps", om.valueToTree(this.getPostPublishSteps()));
            }
            if (this.getPrePublishSteps() != null) {
                data.set("prePublishSteps", om.valueToTree(this.getPrePublishSteps()));
            }
            if (this.getPublishTools() != null) {
                data.set("publishTools", om.valueToTree(this.getPublishTools()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.cdk.JsiiPythonTarget"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            JsiiPythonTarget.Jsii$Proxy that = (JsiiPythonTarget.Jsii$Proxy) o;

            if (!distName.equals(that.distName)) return false;
            if (!module.equals(that.module)) return false;
            if (this.twinePasswordSecret != null ? !this.twinePasswordSecret.equals(that.twinePasswordSecret) : that.twinePasswordSecret != null) return false;
            if (this.twineRegistryUrl != null ? !this.twineRegistryUrl.equals(that.twineRegistryUrl) : that.twineRegistryUrl != null) return false;
            if (this.twineUsernameSecret != null ? !this.twineUsernameSecret.equals(that.twineUsernameSecret) : that.twineUsernameSecret != null) return false;
            if (this.postPublishSteps != null ? !this.postPublishSteps.equals(that.postPublishSteps) : that.postPublishSteps != null) return false;
            if (this.prePublishSteps != null ? !this.prePublishSteps.equals(that.prePublishSteps) : that.prePublishSteps != null) return false;
            return this.publishTools != null ? this.publishTools.equals(that.publishTools) : that.publishTools == null;
        }

        @Override
        public final int hashCode() {
            int result = this.distName.hashCode();
            result = 31 * result + (this.module.hashCode());
            result = 31 * result + (this.twinePasswordSecret != null ? this.twinePasswordSecret.hashCode() : 0);
            result = 31 * result + (this.twineRegistryUrl != null ? this.twineRegistryUrl.hashCode() : 0);
            result = 31 * result + (this.twineUsernameSecret != null ? this.twineUsernameSecret.hashCode() : 0);
            result = 31 * result + (this.postPublishSteps != null ? this.postPublishSteps.hashCode() : 0);
            result = 31 * result + (this.prePublishSteps != null ? this.prePublishSteps.hashCode() : 0);
            result = 31 * result + (this.publishTools != null ? this.publishTools.hashCode() : 0);
            return result;
        }
    }
}
